ErrorCode

Enum ErrorCode 

#[repr(u16)]
pub enum ErrorCode {
Show 16 variants Unknown = 0, InternalError = 1, InvalidRequest = 2, AuthenticationFailed = 3, TenantNotFound = 4, StreamNotFound = 5, TableNotFound = 6, QueryParseError = 7, QueryExecutionError = 8, PositionAhead = 9, StreamAlreadyExists = 10, InvalidOffset = 11, StorageError = 12, ProjectionLag = 13, RateLimited = 14, NotLeader = 15,
}
Error codes for wire protocol errors.

Variants



Unknown = 0

Unknown error.



InternalError = 1

Internal server error.



InvalidRequest = 2

Invalid request format.



AuthenticationFailed = 3

Authentication failed.



TenantNotFound = 4

Tenant not found.



StreamNotFound = 5

Stream not found.



TableNotFound = 6

Table not found.



QueryParseError = 7

Query parse error.



QueryExecutionError = 8

Query execution error.



PositionAhead = 9

Position ahead of current.



StreamAlreadyExists = 10

Stream already exists.



InvalidOffset = 11

Invalid stream offset.



StorageError = 12

Storage error.



ProjectionLag = 13

Projection lag.



RateLimited = 14

Rate limit exceeded.



NotLeader = 15

Not the leader - client should retry on another node.

This error is returned in cluster mode when a write request is sent to a follower replica. The error message may include a leader hint to help the client redirect.