Frame

Struct Frame 

pub struct Frame {
    pub header: FrameHeader,
    pub payload: Bytes,
}
A complete frame with header and payload.

Fields

header: FrameHeader

Frame header.

payload: Bytes

Payload bytes.

Implementations

Source

impl Frame

pub fn new(payload: Bytes) -> Self

Creates a new frame from a payload.

pub fn encode(&self, buf: &mut BytesMut)

Encodes the frame to a byte buffer.

pub fn encode_to_bytes(&self) -> Bytes

Encodes the frame to a new byte buffer.

pub fn decode(buf: &mut BytesMut) -> WireResult<Option<Self>>

Attempts to decode a frame from a byte buffer.

Returns Ok(Some(frame)) if a complete frame was decoded. Returns Ok(None) if more bytes are needed. Returns Err if the frame is invalid.

On success, the consumed bytes are removed from the buffer.

pub fn total_size(&self) -> usize

Returns the total size of the frame in bytes.