pub struct Frame {
pub header: FrameHeader,
pub payload: Bytes,
}Expand description
A complete frame with header and payload.
Fields
header: FrameHeaderFrame header.
payload: BytesPayload bytes.
Implementations
Sourceimpl Frame
impl Frame
Sourcepub fn encode_to_bytes(&self) -> Bytes
pub fn encode_to_bytes(&self) -> Bytes
Encodes the frame to a new byte buffer.
Sourcepub fn decode(buf: &mut BytesMut) -> WireResult<Option<Self>>
pub fn decode(buf: &mut BytesMut) -> WireResult<Option<Self>>
Attempts to decode a frame from a byte buffer.
Returns Ok(Some(frame)) if a complete frame was decoded.
Returns Ok(None) if more bytes are needed.
Returns Err if the frame is invalid.
On success, the consumed bytes are removed from the buffer.
Sourcepub fn total_size(&self) -> usize
pub fn total_size(&self) -> usize
Returns the total size of the frame in bytes.